@@ -167,39 +167,32 @@ int main ( int argc, char ** argv )
   ******************************/
 
 static GnomeUIInfo help_menu[] = {
-  GNOMEUIINFO_HELP(APPNAME),
-  {GNOME_APP_UI_ITEM, N_("_About..."), 
-   N_("Tell about this application"), 
-   about_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
-  GNOMEUIINFO_END
+	GNOMEUIINFO_HELP(APPNAME),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo file_menu[] = {
-  {GNOME_APP_UI_ITEM, 
-   N_("_Save..."), N_("Write information to disk"), 
-   save_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 's', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_SEPARATOR,
-  {GNOME_APP_UI_ITEM, N_("_Preferences..."), 
-   N_("Change application preferences"),
-   preferences_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 'p', 
-   GDK_CONTROL_MASK, NULL },
-  {GNOME_APP_UI_ITEM, N_("E_xit"), 
-   N_("Quit the application"),
-   delete_event_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_END
+	{GNOME_APP_UI_ITEM, 
+		N_("_Save..."), N_("Write information to disk"), 
+		save_cb, NULL, NULL,
+		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, GNOME_KEY_NAME_SAVE_AS, 
+		GNOME_KEY_MOD_SAVE_AS, NULL },
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_EXIT_ITEM(delete_event_cb,NULL),
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo settings_menu[] = {
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cb,NULL),
+	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo main_menu[] = {
-  GNOMEUIINFO_SUBTREE (N_("_File"), file_menu),
-#define MENU_HELP_POS 1
-  GNOMEUIINFO_SUBTREE (N_("_Help"), help_menu),
-  GNOMEUIINFO_END
+	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+	GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
+	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
+	GNOMEUIINFO_END
 };
 
 static void prepare_app()
@@ -213,8 +206,6 @@ static void prepare_app()
 
   gnome_app_create_menus(GNOME_APP(app), main_menu);
 
-  gtk_menu_item_right_justify(GTK_MENU_ITEM(main_menu[MENU_HELP_POS].widget));
-
   app_box = gtk_vbox_new ( FALSE, GNOME_PAD );
   gtk_container_border_width(GTK_CONTAINER(app_box), GNOME_PAD);
 
@@ -372,7 +363,7 @@ static void reset_list(GtkCList * list)
         ++col;
       }
           
-      gtk_clist_append(list, row_text);
+      gtk_clist_append(list, (gchar **)row_text);
 
       returned = fgets(buffer, bufsize, f);
     } 
@@ -466,7 +457,7 @@ static void preferences_cb(GtkWidget *w, gpointer data)
   name_entry = gtk_entry_new();
   command_entry = gtk_entry_new();
 
-  list = gtk_clist_new_with_titles(2, titles);
+  list = gtk_clist_new_with_titles(2, (gchar **)titles);
   sw = gtk_scrolled_window_new (NULL, NULL);
   gtk_container_add (GTK_CONTAINER (sw), list);
   gtk_clist_set_shadow_type(GTK_CLIST(list), GTK_SHADOW_OUT);
@@ -609,7 +600,7 @@ static void new_action_in_prefs(GtkCList * list, gchar * name, gchar * command)
   text[0] = name;
   text[1] = command;
 
-  new_row = gtk_clist_append(list, text);
+  new_row = gtk_clist_append(list, (gchar **)text);
 
   gtk_clist_select_row(list, new_row, 0);
 
